Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: pkg/kernel/lib/canonical_name.dart

Issue 2781893004: Remove definitions from Kernel canonical names. (Closed)
Patch Set: Update test expectations. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/kernel/lib/ast.dart ('k') | runtime/tests/vm/vm.status » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/kernel/lib/canonical_name.dart
diff --git a/pkg/kernel/lib/canonical_name.dart b/pkg/kernel/lib/canonical_name.dart
index 7bf05dc4507ccf12ad724daf9d10de4e9a5a5f29..f4d2deffb6d12a729ac3758fb1d1d2867148dec6 100644
--- a/pkg/kernel/lib/canonical_name.dart
+++ b/pkg/kernel/lib/canonical_name.dart
@@ -30,7 +30,7 @@ import 'ast.dart';
/// "@fields"
/// Qualified name
///
/// Procedure that is not an accessor:
/// Canonical name of enclosing class or library
/// "@methods"
/// Qualified name
@@ -45,6 +45,11 @@ import 'ast.dart';
/// "@setters"
/// Qualified name
///
+/// Procedure that is a factory:
+/// Canonical name of enclosing class
+/// "@factories"
+/// Qualified name
+///
/// Qualified name:
/// if private: URI of library
/// Name text
@@ -136,6 +141,7 @@ class CanonicalName {
if (member is Procedure) {
if (member.isGetter) return '@getters';
if (member.isSetter) return '@setters';
+ if (member.isFactory) return '@factories';
return '@methods';
}
if (member is Field) {
@@ -30,7 +30,7 @@ import 'ast.dart';
/// Qualified name
///
-/// Procedure that is not an accessor:
+/// Procedure that is not an accessor or factory:
/// Canonical name of enclosing class or library
/// "@methods"
« no previous file with comments | « pkg/kernel/lib/ast.dart ('k') | runtime/tests/vm/vm.status » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698